        (function () {
            'use strict';
            
            // Set GSAP defaults...
            gsap.defaults({overwrite: "auto"});
            
            // Register GSAP Plugins...
            gsap.registerPlugin(CSSRulePlugin, Draggable, EasePack, InertiaPlugin, ScrollTrigger, TextPlugin);
            
            if (typeof NV === 'undefined'){var NV={};}
            NV.dw = $(document).width();
            NV.dh = $(document).height();
            NV.ww = $(window).width();
            NV.wi = $(window).innerWidth();
            NV.wh = $(window).height();
            NV.st = $(window).scrollTop();
            NV.winWidth = Math.max(NV.ww, NV.wi);
            NV.isResizing = false;
            
            NV.responsiveIndex = 0;
            NV.previousResponsiveIndex = 4;
            NV.responsiveViewLabels = ["mobile", "tablet", "laptop", "desktop", "ultra"];
            NV.responsiveViewLabel = NV.responsiveViewLabels[NV.responsiveIndex];
            NV.saOpen = false;
            NV.saReady = false;
            
            NV.totalCallouts = 10;
            NV.firstCalloutId = 1;
            NV.lastCalloutId = NV.totalCallouts;
            NV.currentCalloutId = 1;
            NV.nextCalloutId = 2;
            NV.autoplayCallouts = true;
            NV.autoplayCalloutsDisabled = true;
            NV.calloutDotsShowing = false;
            
            // Asset Path Prefixes
            NV.imageAssetsPrefix = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/";
            NV.videoAssetsPrefix = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/videos/design/";
            
            // Background container
            NV.bgContainer = document.getElementById("exploded-view-bg");
            
            // Background image of GeForce RTX 3080
            NV.explodedViewImage = document.getElementById("exploded-view-image");
            NV.bgImageSrc = NV.imageAssetsPrefix + "geforce-rtx-3080-design-exploded-001.jpg";
            
            // Background video of GeForce RTX 3080
            NV.explodedViewVideo = document.getElementById("exploded-view-video");
            NV.bgVideoSrc = NV.videoAssetsPrefix + "geforce-rtx-3080-design-exploded_final.mp4";
            
            // Foreground container
            NV.fgContainer = document.getElementById("exploded-view-fg");
            
            // Foreground image of Air Flow
            NV.airflowImage = document.getElementById("air-flow-image"); 
            NV.fgImageSrc = NV.imageAssetsPrefix + "geforce-rtx-3080-design-airflow-01.jpg";
            
            // Foreground video of Air Flow
            NV.airflowVideo = document.getElementById("air-flow-video");
            NV.fgVideoSrc = NV.videoAssetsPrefix + "geforce-rtx-3080-design-airflow_final.mp4";
            
            NV.timelineExplodedViewIntroReady = false;
            NV.timelineExplodedViewOutroReady = false;
            NV.timelineFanSpinLoopReady = false;
            
            NV.explodedViewVideo.style.opacity = 0;
            
            NV.fanspinShowing = false;
            
            NV.airflowVideo.style.opacity = 0;
            
            NV.airflowShowing = false;
            
            NV.explodedViewScrollTriggerReady = false;
            
            NV.explodedViewVideoReady = false;
            NV.explodedViewVideoCanPlay = false;
            NV.explodedViewVideoCanPlayThrough = false;
            
            NV.is_Mobile = (/Android|webOS|iPhone|iPad|iPod|BB10|PlayBook|BlackBerry|Silk/.test(navigator.userAgent));
            NV.is_iOS = (!!navigator.userAgent.match(/iP(hone|ad)/i));
            NV.is_iPhone = (/iPad|iPhone/.test(navigator.userAgent));
            NV.is_iPadPro = (navigator.userAgent.match(/Mac/) && navigator.maxTouchPoints && navigator.maxTouchPoints > 2) ? true : false;
            if (NV.is_iPadPro) NV.is_Mobile = true; 		
            NV.is_Android = (/Android/.test(navigator.userAgent));
            NV.is_Desktop = (!NV.isMobile);
            NV.is_Firefox = (navigator.userAgent.toLowerCase().indexOf('firefox') > -1);
            NV.is_Chrome = (/Chrome/.test(navigator.userAgent) && /Google Inc/.test(navigator.vendor));
            NV.is_Safari = (/Safari/.test(navigator.userAgent) && /Apple Computer/.test(navigator.vendor));
            NV.is_Edge = (navigator.appVersion.indexOf('Edge') > -1);
            NV.is_MSIE = (navigator.appName == 'Microsoft Internet Explorer') ? true : (navigator.appVersion.indexOf('Trident') > -1) ? true : false;
            NV.is_IE11 = !!window.MSInputMethodContext && !!document.documentMode;
            
            if (NV.is_Mobile == true || NV.is_MSIE == true || NV.is_IE11 == true || NV.is_Safari == true) {
                console.log("DESIGN - FALLBACK MODE: TRUE");
                NV.fallbackMode = true;
            } else {
                console.log("DESIGN - FALLBACK MODE: FALSE");
                NV.fallbackMode = false;
            }
            
            //console.log("FALLBACK FORCED TO TRUE FOR ALL");
            //NV.fallbackMode = true;
            
            
            NV.disableAirflow = true;
            
            if (NV.disableAirflow == true) {
                
                NV.airflowImage.style.display = "none";
                NV.airflowImage.src = "";
                
                NV.airflowVideo.style.display = "none";
                NV.airflowVideo.src = "";
            }
            
            
            // Cache all Callout selectors...
            
            function cacheCalloutSelectors() {
                
                //console.log("cacheCalloutSelectors()");
                
                NV.calloutDots = document.querySelector("#callout-dots");       //console.log("NV.calloutDots =", "#callout-dots");
                NV.calloutDotClass = document.querySelector(".callout-dot");    //console.log("NV.calloutDotClassItems =", ".callout-dot");
                
                NV.callouts = document.querySelector("#callouts");              //console.log("NV.callouts =", "#callouts");
                NV.calloutClass = document.querySelector(".callout");           //console.log("NV.calloutClassItems =", ".callout");
                
                var i = NV.totalCallouts;
                while (i--) {
                    // Cache all Callout selectors by ID...
                    NV["callout" + (i + 1)] = document.getElementById('callout' + (i + 1));
                    NV["callout" + (i + 1)].style.opacity = 0;
                    //console.log("NV.callout" + (i + 1) + " cached from " + "#callout" + (i + 1));
                }
                i = NV.totalCallouts;
                while (i--) {
                    // Cache all Callout Dot selectors by ID...
                    NV["calloutDot" + (i + 1)] = document.getElementById('callout-dot' + (i + 1));
                    //NV["calloutDot" + (i + 1)].id = (i + 1);
                    NV["calloutDot" + (i + 1)].style.opacity = 0;
                    //console.log("NV.calloutDot" + (i + 1) + " cached from " + "#callout-dot" + (i + 1), "and numeric id is: " + NV["calloutDot" + (i + 1)].id);
                }
            }
            
            cacheCalloutSelectors();
            
            function startThrottledResize(_n) {
                if (_n === 1) {
                    NV.delayedVar1 = setTimeout(function() {
                        NV.isResizing = false;
                        //console.log('Resize complete.');
                    }, 500);
                }
            }
            
            function stopThrottledResize(_n) {
                if (_n === 1) {
                    clearTimeout(NV.delayedVar1);
                }
            }
            
            function checkSize() {
                
                NV.isResizing = true;
                NV.ww = $(window).width();
                NV.wh = $(window).height();
                NV.dw = $(document).width();
                NV.dh = $(document).height();
                NV.winWidth = Math.max( $(window).width(), $(window).innerWidth() );
                
                if (NV.winWidth < 640) {
                    // MOBILE
                    NV.responsiveIndex = 0;
                } else if (NV.winWidth >= 640 && NV.winWidth < 1024) {
                    // TABLET
                    NV.responsiveIndex = 1;
                } else if (NV.winWidth >= 1024 && NV.windWidth < 1350) {
                    // LAPTOP
                    NV.responsiveIndex = 2;
                } else if (NV.winWidth >= 1350 && NV.winWidth < 2560) {
                    // DESKTOP
                    NV.responsiveIndex = 3;
                } else if (NV.winWidth >= 2560) {
                    // ULTRA-WIDE DESKTOP
                    NV.responsiveIndex = 4;
                }
                
                if (NV.responsiveIndex !== NV.previousResponsiveIndex) {
                    NV.responsiveViewLabel = NV.responsiveViewLabels[NV.responsiveIndex];
                    //console.log("checkSize :: responsiveView:", NV.responsiveViewLabel);
                    if (NV.explodedViewScrollTriggerReady == true) {ScrollTrigger.refresh();}
                }
                
                NV.previousResponsiveIndex = NV.responsiveIndex;
                
                NV.isResizing = false;
                
                stopThrottledResize(1);
                startThrottledResize(1);
            }
            
            $(document).ready(function() {
                
                //console.log('Design ready...');
                
                // Check the browser window's width on initial page load...
                checkSize();
                
                // Check the browser window's width on resize...
                $(window).resize(checkSize);
                
                initAnimationTimelines();
                
            });
            
            // Initialize Animation Timelines, only one time is permitted...
            
            function initAnimationTimelines() {
                
                //console.log("initAnimationTimelines?");
                
                if (NV.saReady) return;
                
                //console.log("Yes, initAnimationTimelines...");
                
                if (NV.fallbackMode == false) {
                    
                    //console.log("VIDEO MODE: setting video properties...");
                    
                    // exploded video
                    NV.explodedViewVideo.pause();
                    NV.explodedViewVideo.currentTime = 0;
                    
                    // airflow video
                    if (NV.disableAirflow == false) {
                        NV.airflowVideo.pause();
                    }
                    
                    //NV.fgContainer.style.opacity = 0;
                    //NV.airflowVideo.style.opacity = 0;
                    //NV.airflowImage.style.opacity = 0;
                    
                    gsap.set(NV.fgContainer, {autoAlpha: 0});
                    gsap.set(NV.airflowVideo, {autoAlpha: 0});
                    gsap.set(NV.airflowImage, {autoAlpha: 0});
                    
                    NV.explodedViewVideo.oncanplay = function() {
                        
                        if (!NV.explodedViewVideoCanPlay == false) {
                            //console.log('Exploded view can play...');
                            NV.explodedViewVideoCanPlay = true;
                        }
                        
                    }

                    NV.explodedViewVideo.oncanplaythrough = function() {

                        if (!NV.explodedViewVideoCanPlayThrough) {

                            //console.log('Exploded view can play through...');

                            //setTimeout(function(){initExplodedView();}, 1500);
                            
                            initExplodedView();
                            
                            NV.explodedViewVideoCanPlayThrough = true;
                            
                        }
                    }
                    
                } else if (NV.fallbackMode == true) {
                    
                    //console.log("FALLBACK MODE: disabling videos...");
                    
                    NV.explodedViewVideo.src = "";
                    NV.explodedViewVideo.style.display = "none";
                    
                    NV.airflowVideo.src = "";
                    NV.airflowVideo.style.display = "none";
                    
                    setTimeout(function(){initExplodedView();}, 1000);
                    
                }
                
                NV.calloutDots.style.opacity = 0;
                NV.callouts.style.opacity = 0;
                
                NV.saReady = true;
            }

            function initExplodedView() {
                
                //console.log("initExplodedView?");
                
                checkSize();
                
                if (NV.explodedViewVideoReady == false) {
                    
                    //console.log('Yes, initializing exploded view...');
                    
                    if (NV.fallbackMode == false) {
                        
                        //console.log('VIDEO MODE...');
                    
                        //console.log("video duration is ", Math.floor(NV.explodedViewVideo.duration));
                    
                        NV.timelineExplodedSequence = gsap.timeline({paused: true}).fromTo(NV.explodedViewVideo, {currentTime: 0}, {duration: Math.floor(NV.explodedViewVideo.duration), currentTime: NV.explodedViewVideo.duration, ease: "linear"});
                        
                        
                        
                        NV.explodedViewVideoReady = true;
                        
                    } else {
                        
                        //console.log('FALLBACK MODE...');
                        
                        NV.explodedViewVideoReady = true;
                    }
                    
                    gsap.killTweensOf(initExplodedViewScrollTrigger);
                    gsap.delayedCall(1, initExplodedViewScrollTrigger);
                    
                }
            }
            
            function initExplodedViewScrollTrigger() {
                
                //console.log("initExplodedViewScrollTrigger?");
                
                if (NV.explodedViewScrollTriggerReady == true) {
                    //console.log("No, already called initExplodedViewScrollTrigger before.");
                    return;
                }
                
                //console.log("Yes, initExplodedViewScrollTrigger()");
                
                // SCROLL TRIGGER
                
                ScrollTrigger.create({
                    trigger: "#design",
                    start: "top 45%",
                    end: "bottom 55%",
                    onEnter: function(){introOutroExplodedView("onEnter")},
                    onEnterBack: function(){introOutroExplodedView("onEnterBack")},
                    onLeave: function(){introOutroExplodedView("onLeave")},
                    onLeaveBack: function(){introOutroExplodedView("onLeaveBack")},
                    //onEnter: () => introOutroExplodedView("onEnter"),
                    //onEnterBack: () => introOutroExplodedView("onEnterBack"),
                    //onLeave: () => introOutroExplodedView("onLeave"),
                    //onLeaveBack: () => introOutroExplodedView("onLeaveBack"),
                    id: "design",
                    markers: false
                })
                
                ScrollTrigger.refresh();
                NV.explodedViewScrollTriggerReady = true;
            } 
            
            function introOutroExplodedView(_e) {
                
                //console.log('introOutroExplodedView :: INTRO-or-OUTRO EXPLODED VIEW from ScrollTrigger event: ' + _e);
                
                NV.currentScrollTriggerEvent = _e;

                if (_e == "onEnter") {
                    // INTRO...
                    //console.log("onEnter");
                    NV.explodedViewInRange = true;
                    //if (NV.fallbackMode == false) {
                        gsap.to(NV.explodedViewVideo, {duration: 0.01, autoAlpha: 1, ease: "expo", delay: 0.5});
                    //}
                    gsap.killTweensOf(playExplodedView);
                    gsap.delayedCall(0.56, playExplodedView);
                    
                } else if (_e == "onEnterBack") {
                    // INTRO...
                    //console.log("onEnterBack");
                    NV.explodedViewInRange = true;
                    //if (NV.fallbackMode == false) {
                        gsap.to(NV.explodedViewVideo, {duration: 0.01, autoAlpha: 1, ease: "expo", delay: 0.5});
                    //}
                    gsap.killTweensOf(playExplodedView);
                    gsap.delayedCall(0.56, playExplodedView);
                    
                } else if (_e == "onLeave") {
                    // OUTRO...
                    //console.log("onLeave");
                    NV.explodedViewInRange = false;
                    exitExplodedView();
                } else if (_e == "onLeaveBack") {
                    // OUTRO...
                    //console.log("onLeaveBack");
                    NV.explodedViewInRange = false;
                    exitExplodedView();
                }
            }
            
            function playExplodedView() {
                
                //console.log('playExplodedView()... ');
                
                gsap.set(NV.bgContainer, {autoAlpha: 1});
                
                if (NV.fallbackMode == false) {

                    if (NV.timelineExplodedViewIntroReady == false) {

                        var introEndFrame = (43/119);
                        introEndFrame = Number(introEndFrame);
                        //console.log("NV.timelineExplodedSequence ==> NV.timelineExplodedViewIntro tweening from progress 0 to", introEndFrame);

                        NV.timelineExplodedViewIntro = gsap.timeline({paused: false}).fromTo(NV.timelineExplodedSequence, {progress: 0}, {duration: 1, progress: introEndFrame, ease: "linear"});
                        NV.timelineExplodedViewIntro.restart();
                        NV.timelineExplodedViewIntroReady = true;

                    } else {
                        NV.timelineExplodedViewIntro.restart();
                    }
                    
                }
                
                showFanSpinLoop();
                
                gsap.killTweensOf(playFanSpinLoop);
                gsap.delayedCall(1.01, playFanSpinLoop);
                
                gsap.killTweensOf(showExplodedViewPosterFrame);
                gsap.delayedCall(1.1, showExplodedViewPosterFrame);
            }
            
            function showExplodedViewPosterFrame() {
                if (NV.explodedViewImage.src != "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-045.jpg") {
                    NV.explodedViewImage.src = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-045.jpg";
                }
            }
            
            function showFanSpinLoop() {
                
                if (NV.fanspinShowing == true) return;
                
                //console.log('showFanSpinLoop()... ');
                
                gsap.set(NV.bgContainer, {autoAlpha: 1});
                
                gsap.to(NV.explodedViewImage, {duration: 0.5, autoAlpha: 1, delay: 0.5});
                
                if (NV.fallbackMode == false) {
                    //gsap.to(NV.explodedViewVideo, {duration: 0.5, autoAlpha: 1, ease: "expo"});
                    gsap.set(NV.explodedViewVideo, {autoAlpha: 1});
                }
                
                NV.fanspinShowing = true;
            }
            
            function hideFanSpinLoop() {
                
                if (NV.fanspinShowing == false) return;
                
                //console.log('hideFanSpinLoop()... ');
                
                gsap.set([NV.explodedViewImage, NV.bgContainer], {autoAlpha: 1});
                
                NV.fanspinShowing = false;
            }
            
            function resetToPosterFrame() {
                
                //console.log("resetToPosterFrame: ", NV.currentScrollTriggerEvent);

                if (NV.currentScrollTriggerEvent == "onLeave"){
                    
                    if (NV.fallbackMode == true) {
                        if (NV.explodedViewImage.src != "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-027.jpg") {
                            NV.explodedViewImage.src = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-027.jpg";
                        }
                    } else {
                        if (NV.explodedViewImage.src != "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-001.jpg") {
                            NV.explodedViewImage.src = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-001.jpg";
                        }
                    }
                    
                } else {
                    if (NV.explodedViewImage.src != "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-001.jpg") {
                        NV.explodedViewImage.src = "/content/dam/en-zz/Solutions/geforce/ampere/rtx-3080/images/design/geforce-rtx-3080-design-exploded-001.jpg";
                    }
                }
            }
            
            function playFanSpinLoop() {
                
                //console.log('playFanSpinLoop()... ');
                
                if (NV.fanspinShowing == false) { showFanSpinLoop(); }
                
                if (NV.timelineFanSpinLoopReady == false) {
                    
                    if (NV.fallbackMode == false) {
                        
                        var fanSpinStartFrame = (44/119);
                        fanSpinStartFrame = Number(fanSpinStartFrame);

                        var fanSpinEndFrame = (89/119);
                        fanSpinEndFrame = Number(fanSpinEndFrame);

                        //console.log("NV.timelineExplodedSequence ==> NV.timelineFanSpinLoopReady tweening from progress", fanSpinStartFrame, "to", fanSpinEndFrame);

                        NV.timelineFanSpinLoop = gsap.timeline({paused: true, repeat: -1, timeScale: 1}).fromTo(NV.timelineExplodedSequence, {progress: fanSpinStartFrame}, {duration: 1, progress: fanSpinEndFrame, ease: "linear"});
                        NV.timelineFanSpinLoop.play();

                    }
                    
                    NV.timelineFanSpinLoopReady = true;
                    
                } else {
                    if (NV.fallbackMode == false) {
                        NV.timelineFanSpinLoop.play();
                    }
                }
                
                resumeFanSpinLoop();
                
                showCalloutDots();
            }
            
            function pauseFanSpinLoop() {
                
                //console.log('pauseFanSpinLoop()... ');
                
                gsap.set(NV.bgContainer, {autoAlpha: 1});
                
                if (NV.fallbackMode == false) {
                    gsap.to(NV.timelineFanSpinLoop, {duration: 1, timeScale: 0, ease: "sine.out"});
                }

                resetToPosterFrame();
            }
            
            function resumeFanSpinLoop() {
                
                //console.log('resumeFanSpinLoop()...');
                
                gsap.set(NV.bgContainer, {autoAlpha: 1});
                
                if (NV.fallbackMode == false) {
                    gsap.to(NV.timelineFanSpinLoop, {duration: 1, timeScale: 0.66, ease: "sine.in"});
                }
            }
            
            function showAirflow() {
                
                if (NV.airflowShowing == true || NV.disableAirflow == true) {return;}
                
                // Only show airflow if its not already showing...
                
                //console.log('showAirflow()...');
                
                //NV.fgContainer.style.opacity = 1;
                gsap.to(NV.fgContainer, {duration: 1, autoAlpha: 1, ease: "expo.inOut"});
                
                if (NV.fallbackMode == false) {
                    NV.airflowVideo.play();
                    gsap.to(NV.airflowVideo, {duration: 1, autoAlpha: 1});
                }
                
                NV.airflowShowing = true;
            }
            
            function hideAirflow() {
                
                if (NV.airflowShowing == false || NV.disableAirflow == true) {return;}
                
                // Only hide airflow if its not already hidden...
                
                //console.log('hideAirflow()...');
                
                if (NV.fallbackMode == false) {
                    
                    gsap.to(NV.airflowVideo, {duration: 0.5, autoAlpha: 0, delay: 0, onComplete: function(){
                        //NV.fgContainer.style.opacity = 0;
                        gsap.set(NV.fgContainer, {autoAlpha: 0});
                    }});
                    
                } else {
                    gsap.to(NV.fgContainer, {duration: 1, autoAlpha: 0});
                }
                
                NV.airflowShowing = false;
            }
            
            function exitExplodedView() {
                
                //console.log('exitExplodedView()...');
                
                hideCalloutDots();
                
                hideAirflow();
                
                pauseFanSpinLoop();
                
                if (NV.timelineExplodedViewOutroReady == false) {
                    
                    if (NV.fallbackMode == false) {
                        
                        var startFrame = (90/119);
                        startFrame = Number(startFrame);
                        
                        NV.timelineExplodedViewOutro = gsap.timeline({paused: true}).fromTo(NV.timelineExplodedSequence, {progress: startFrame}, {duration: 1, progress: 1, ease: "linear", delay: 1});
                        NV.timelineExplodedViewOutro.restart();
                        
                        //console.log("NV.timelineExplodedSequence ==> NV.timelineExplodedViewOutro tweening from progress", startFrame, "to 1");
                    }
                    NV.timelineExplodedViewOutroReady = true;
                } else {
                    if (NV.fallbackMode == false) {
                        NV.timelineExplodedViewOutro.restart();
                    }
                }
                
                gsap.to(NV.explodedViewVideo, {duration: 1, opacity: 0, delay: 2, onStart: function (){
                    hideFanSpinLoop();
                }});
                
                gsap.killTweensOf(killCallouts);
                gsap.delayedCall(1, killCallouts);
                
                gsap.killTweensOf(hideCalloutDotsAfterOutro);
                gsap.delayedCall(2, hideCalloutDotsAfterOutro);
            }
            
            function showCalloutDots() {
                
                if (NV.calloutDotsShowing == true) return;
                
                //console.log("showCalloutDots()...");
                
                gsap.killTweensOf(killCallouts);
                gsap.killTweensOf(hideCalloutDots);
                
                gsap.to(NV.calloutDots, {duration: 1, autoAlpha: 1, ease: "expo.out", overwrite: 1});
                
                gsap.to('#callouts', {duration: 1, autoAlpha: 1, ease: "expo.out", overwrite: 1});
                
                showCalloutsAfterIntro();
                
                NV.calloutDotsShowing = true;
            }
            
            function showCallout(_id, _autoplay) {
                
                if (!_autoplay) {
                    gsap.killTweensOf(showCallout);
                    gsap.killTweensOf(nextCallout);
                    gsap.killTweensOf(autoplayNextCallout);
                }
                
                //console.log("showCallout( _id:", _id, "_autoplay:", _autoplay, ")");
                
                gsap.to(NV["callout" + _id], {duration: 1, autoAlpha: 1});
                //document.getElementById('callout-line' + _id).style.visibility = 'visible';
                gsap.to(NV["calloutDot" + _id], { duration: .5, scale: 1.75, force3D: false, ease:Expo.easeOut, overwrite: 1, delay: 0.1});
                //gsap.to('#callout-line' + _id, 1, {css: {autoAlpha: 1}, ease:Cubic.easeOut, overwrite: 1, delay: 0.1});
                
                var i = (NV.totalCallouts + 1);
                
                while(i--) {
                    if (i != _id && i > 0) {
                        hideCallout(i);
                    } else {
                        if (_id >= 6) {
                            hideFanSpinLoop();
                            showAirflow();
                        } else {
                            showFanSpinLoop();
                            hideAirflow();
                        }
                    }
                }
            }
            
            function showCalloutsAfterIntro() {
                
                //console.log('showCalloutsAfterIntro()...');
                
                if (NV.autoplayCallouts == true) {NV.autoplayCalloutsDisabled = false;}
                
                // Cache all Callout elements...
                
                var i = NV.totalCallouts;
                
                while (i--) {
                    // Make all Callout Dots visible...
                    gsap.fromTo("#callout-dot" + (i + 1), {autoAlpha: 0}, {duration: 0.5, autoAlpha: 1, ease: "cubic.out", delay: 0.05 * (i + 1)});
                }
                
                // Add hover behaviors...
                $('#callout-dot1').hover(function () {showCallout (1, false);}, function () {autoplayNextCallout(1, NV.totalCallouts);});
                $('#callout-dot2').hover(function () {showCallout (2, false);}, function () {autoplayNextCallout(2, NV.totalCallouts);});
                $('#callout-dot3').hover(function () {showCallout (3, false);}, function () {autoplayNextCallout(3, NV.totalCallouts);});
                $('#callout-dot4').hover(function () {showCallout (4, false);}, function () {autoplayNextCallout(4, NV.totalCallouts);});
                $('#callout-dot5').hover(function () {showCallout (5, false);}, function () {autoplayNextCallout(5, NV.totalCallouts);});
                $('#callout-dot6').hover(function () {showCallout (6, false);}, function () {autoplayNextCallout(6, NV.totalCallouts);});
                $('#callout-dot7').hover(function () {showCallout (7, false);}, function () {autoplayNextCallout(7, NV.totalCallouts);});
                $('#callout-dot8').hover(function () {showCallout (8, false);}, function () {autoplayNextCallout(8, NV.totalCallouts);});
                $('#callout-dot9').hover(function () {showCallout (9, false);}, function () {autoplayNextCallout(9, NV.totalCallouts);});
                $('#callout-dot10').hover(function () {showCallout (10, false);}, function () {autoplayNextCallout(10, NV.totalCallouts);});
                
                gsap.killTweensOf(showCallout);
                gsap.delayedCall(1, showCallout, [1, true]);
                
                gsap.killTweensOf(autoplayNextCallout);
                gsap.delayedCall(6, autoplayNextCallout, [1, NV.totalCallouts]);
            }
            
            function hideCalloutDotsAfterOutro() {
                hideCalloutDots();
            }
            
            function hideCalloutDots() {
                
                if (NV.calloutDotsShowing == false) { return; }
                
                //console.log('hideCalloutDots()...');
                
                var i = NV.totalCallouts + 1;
                while(i--) {
                    if (i > 0) {
                        //gsap.to(('#callout-line' + i), .01, {autoAlpha: 0, ease:Cubic.easeOut, delay: i * 0.05, overwrite: 1});
                        gsap.to($('#callout-dot' + i), .5, {autoAlpha: 0, scale: 1, ease:Cubic.easeOut, delay: i * 0.05, overwrite: 1});
                        //console.log("hiding... " + ('#callout-dot' + i));
                    }
                }
                
                NV.calloutDotsShowing = false;
            }
            
            function hideCallouts() {
                
                //console.log('hideCallouts()...');
                
                var i = NV.totalCallouts + 1;
                while(i--) {
                    if (i > 0) {
                        //gsap.to(('#callout-line' + i), .01, {autoAlpha: 0, ease:Cubic.easeOut, delay: i * 0.05, overwrite: 1});
                        gsap.to($('#callout' + i), .5, {autoAlpha: 0, ease:Cubic.easeOut, delay: i * 0.05, overwrite: 1});
                        
                        //console.log("hiding... " + ('#callout' + i));
                    }
                }
            }
            
            function killCallouts() {
                
                //console.log("killCallouts()...");
                
                NV.autoplayCalloutsDisabled = true;
                
                gsap.killTweensOf(showCallout); 
                gsap.killTweensOf(nextCallout); 
                gsap.killTweensOf(autoplayNextCallout);
                
                var i = (NV.totalCallouts + 1);
                while(i--) {
                    if (i > 0) {
                        $('#callout-dot' + i).off('hover');
                        $('#callout-dot' + i).unbind('hover mouseenter mouseleave');
                        gsap.to(('#callout' + i), {duration: 0.1, autoAlpha: 0, ease: "expo", overwrite: 1});
                    }
                }
                
                gsap.to('#callouts', {duration: 0.5, autoAlpha: 0, ease: "expo"});
            }
            
            function hideCallout(_id) {
                
                //console.log('hideCallout()...', _id);
                
                if (_id > 0 && _id < (NV.totalCallouts + 1)) {
                    gsap.to('#callout-dot' + _id, {duration: .5, scale: 1, force3D: false, ease: "expo.out", overwrite: 1, delay: 0.01});
                    //gsap.to('#callout-line' + _id, .5, {autoAlpha: 0, ease: "cubic.out", delay: 0.01});
                    gsap.to('#callout' + _id, {duration: .5, autoAlpha: 0, ease: "cubic.out", delay: 0.01});
                }
            }
            
            function autoplayNextCallout(_id, _total) {
                
                if (NV.autoplayCalloutsDisabled == true) {
                    gsap.killTweensOf(showCallout);
                    gsap.killTweensOf(nextCallout);
                    gsap.killTweensOf(autoplayNextCallout);
                    return;
                }
                //console.log("autoplayNextCallout :: _id:", _id, "_total:", _total);
                
                gsap.killTweensOf(nextCallout);
                gsap.delayedCall(0.5, nextCallout, [_id]);
                
                NV.nextId = (_id + 1 < _total) ? (_id + 1) : 1;
                gsap.killTweensOf(autoplayNextCallout);
                gsap.delayedCall(8, autoplayNextCallout, [NV.nextId, NV.totalCallouts]);
            }
            
            function nextCallout(_id) {
                
                hideCallout(_id);
                NV.nextId = (_id + 1 < (NV.totalCallouts + 1)) ? (_id + 1) : 1;
                
                gsap.killTweensOf(showCallout);
                gsap.delayedCall(1.5, showCallout, [NV.nextId, true]);
            }
        }());